@@ -1,7 +1,7 @@
 package Perinci::Sub::To::POD;
 
-our $DATE = '2015-01-05'; # DATE
-our $VERSION = '0.60'; # VERSION
+our $DATE = '2015-07-07'; # DATE
+our $VERSION = '0.61'; # VERSION
 
 use 5.010001;
 use Log::Any '$log';
@@ -208,8 +208,10 @@ sub after_gen_doc {
             "=over 4",
             "",
         );
+        use experimental 'smartmatch';
         for my $name (sort keys %{$dres->{args}}) {
             my $ra = $dres->{args}{$name};
+            next if 'hidden' ~~ @{ $ra->{arg}{tags} // [] };
             $self->add_doc_lines(join(
                 "",
                 "=item * B<", $name, ">",
@@ -279,7 +281,7 @@ that contains extra information.")), "")
         for my $link (@{ $meta->{links} }) {
             my $url = $link->{url};
             # currently only handles pm: urls (link to another perl module)
-            next unless $url =~ m!\Apm:(?://)?(.+)!;
+            next unless $url =~ m!\Apm:(.+)!;
             my $mod = $1;
             $self->add_doc_lines("* L<$mod>", "");
             $self->add_doc_lines($link->{summary}.".", "") if $link->{summary};
@@ -304,7 +306,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.60 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-01-05.
+This document describes version 0.61 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-07-07.
 
 =head1 SYNOPSIS
 
@@ -326,7 +328,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-Doc>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
