@@ -1,7 +1,7 @@
 package Perinci::Sub::To::Text;
 
-our $DATE = '2015-01-05'; # DATE
-our $VERSION = '0.60'; # VERSION
+our $DATE = '2015-07-07'; # DATE
+our $VERSION = '0.61'; # VERSION
 
 use 5.010001;
 use Log::Any '$log';
@@ -32,6 +32,7 @@ sub after_gen_doc {
     $self->add_doc_lines("", $dres->{summary})     if $dres->{summary};
     $self->add_doc_lines("", $dres->{description}) if $dres->{description};
     if (keys %{$dres->{args}}) {
+        use experimental 'smartmatch';
         $self->add_doc_lines(
             "",
             __("Arguments") .
@@ -43,6 +44,7 @@ sub after_gen_doc {
             my $prev_arg_has_ct = $arg_has_ct;
             $arg_has_ct = 0;
             my $ra = $dres->{args}{$name};
+            next if 'hidden' ~~ @{ $ra->{arg}{tags} // [] };
             $self->add_doc_lines("") if $i++ > 0 && $prev_arg_has_ct;
             $self->add_doc_lines(join(
                 "",
@@ -103,7 +105,7 @@ Perinci::Sub::To::Text - Generate text documentation from Rinci function metadat
 
 =head1 VERSION
 
-This document describes version 0.60 of Perinci::Sub::To::Text (from Perl distribution Perinci-To-Doc), released on 2015-01-05.
+This document describes version 0.61 of Perinci::Sub::To::Text (from Perl distribution Perinci-To-Doc), released on 2015-07-07.
 
 =head1 SYNOPSIS
 
@@ -117,7 +119,8 @@ You can also try the L<peri-doc> script with the C<--format text> option:
  % peri-doc --format text /Some/Module/somefunc
 
 To generate a usage-like help message for a function, you can try
-L<peri-func-usage> which is included in the L<Perinci::CmdLine> distribution.
+L<peri-func-usage> which is included in the L<Perinci::CmdLine::Classic>
+distribution.
 
  % peri-func-usage http://example.com/api/somefunc
 
@@ -129,7 +132,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-Doc>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
