@@ -1,7 +1,7 @@
 package Perinci::To::POD;
 
-our $DATE = '2015-01-05'; # DATE
-our $VERSION = '0.60'; # VERSION
+our $DATE = '2015-07-07'; # DATE
+our $VERSION = '0.61'; # VERSION
 
 use 5.010001;
 use Log::Any '$log';
@@ -127,7 +127,7 @@ sub gen_doc_section_links {
         for my $link (@{ $meta->{links} }) {
             my $url = $link->{url};
             # currently only handles pm: urls (link to another perl module)
-            next unless $url =~ m!\Apm:(?://)?(.+)!;
+            next unless $url =~ m!\Apm:(.+)!;
             my $mod = $1;
             $self->add_doc_lines(
                 "L<$mod>" .
@@ -153,7 +153,7 @@ Perinci::To::POD - Generate POD documentation for a package from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.60 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-01-05.
+This document describes version 0.61 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-07-07.
 
 =head1 SYNOPSIS
 
@@ -166,8 +166,8 @@ You can use the included L<peri-doc> script, or:
 
 To generate documentation for a single function, see L<Perinci::Sub::To::POD>.
 
-To generate a usage-like help message for a single function, you can try
-the L<peri-func-usage> from the L<Perinci::CmdLine> distribution.
+To generate a usage-like help message for a single function, you can try the
+L<peri-func-usage> from the L<Perinci::CmdLine::Classic> distribution.
 
 =for Pod::Coverage .+
 
@@ -177,7 +177,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-Doc>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
