@@ -1,7 +1,7 @@
 package Perinci::To::PackageBase;
 
-our $DATE = '2015-01-05'; # DATE
-our $VERSION = '0.60'; # VERSION
+our $DATE = '2015-07-07'; # DATE
+our $VERSION = '0.61'; # VERSION
 
 use 5.010;
 use Data::Dump::OneLine qw(dump1);
@@ -95,8 +95,10 @@ sub gen_doc_section_functions {
     $dres->{functions} = {};
     for my $furi (@func_uris) {
         my $fname = $furi; $fname =~ s!.+/!!;
+        my $meta = $cmetas->{$furi};
+        next if $meta->{'x.no_index'};
         $dres->{functions}{$furi} =
-            $self->_gen_func_doc(name=>$fname, meta=>$cmetas->{$furi});
+            $self->_gen_func_doc(name=>$fname, meta=>$meta);
     }
 }
 
@@ -118,7 +120,7 @@ Perinci::To::PackageBase - Base class for Perinci::To::* package documentation g
 
 =head1 VERSION
 
-This document describes version 0.60 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2015-01-05.
+This document describes version 0.61 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2015-07-07.
 
 =for Pod::Coverage .+
 
@@ -128,7 +130,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-Doc>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
